@@ -135,6 +135,12 @@ assert args[2] == 5
         # check that it's logged correctly
         self.assertLog(b'^[0-9.]+ Do -1 {"foo": 42} 5$')
 
+    def test_multi_output(self):
+        '''multiple output values'''
+
+        self.dbus_mock.AddMethod('', 'AddSub', 'ii', 'ii', 'ret = (args[0] + args[1], args[0] - args[1])')
+        self.assertEqual(self.dbus_test.AddSub(3, 5), (8, -2))
+
     def test_exception(self):
         '''raise a D-Bus exception'''
 
@@ -466,6 +472,10 @@ assert args[2] == 5
                                       'SigTypeTest',
                                       'iuvao',
                                       [-42, 42, dbus.String('hello', variant_level=1), ['/a', '/b']])
+            self.dbus_mock.EmitSignalDetailed('',
+                                              'SigDetailed',
+                                              'su', ['details', 123],
+                                              {'destination': self.dbus_con.get_unique_name()})
 
         caught = []
         ml = GLib.MainLoop()
@@ -473,7 +483,7 @@ assert args[2] == 5
         def catch(*args, **kwargs):
             if kwargs['interface'].startswith('org.freedesktop.Test'):
                 caught.append((args, kwargs))
-            if len(caught) == 3:
+            if len(caught) == 4:
                 # we caught everything there is to catch, don't wait for the
                 # timeout
                 ml.quit()
@@ -522,6 +532,12 @@ assert args[2] == 5
         self.assertEqual(type(args[3][0]), dbus.ObjectPath)
         self.assertEqual(args[3][0].variant_level, 0)
 
+        # check SigDetailed
+        self.assertEqual(caught[3][0], ('details', 123))
+        self.assertEqual(caught[3][1]['member'], 'SigDetailed')
+        self.assertEqual(caught[3][1]['path'], '/')
+        self.assertEqual(caught[3][1]['interface'], 'org.freedesktop.Test.Main')
+
         # check correct logging
         with open(self.mock_log.name, encoding="UTF-8") as f:
             log = f.read()
@@ -529,6 +545,7 @@ assert args[2] == 5
         self.assertRegex(log, '[0-9.]+ emit / org.freedesktop.Test.Sub.SigTwoArgs "hello" 42\n')
         self.assertRegex(log, '[0-9.]+ emit / org.freedesktop.Test.Sub.SigTypeTest -42 42')
         self.assertRegex(log, r'[0-9.]+ emit / org.freedesktop.Test.Sub.SigTypeTest -42 42 "hello" \["/a", "/b"\]\n')
+        self.assertRegex(log, '[0-9.]+ emit / org.freedesktop.Test.Main.SigDetailed "details" 123\n')
 
     def test_signals_type_mismatch(self):
         '''emitting signals with wrong arguments'''
